[![Build Status](https://travis-ci.org/dilawar/libsoda.svg?branch=master)](https://travis-ci.org/dilawar/libsoda)

## libsoda++

This is `c++11` version of LSODA library. See the `./test_LSODA.cpp` file for example.

## CREDIT 

This work is based on http://lh3lh3.users.sourceforge.net/download/lsoda.c . 

Related projects:

1. https://github.com/sdwfrost/liblsoda
